==> jc-1.4.0.tar.gz: java/beans/beancontext/BeanContextMembershipEvent.h <==
// public class java.beans.beancontext.BeanContextMembershipEvent

// class file dependencies
// @dep_class 83892d580401761a java_beans_beancontext_BeanContextEvent
// @dep_class 5efb8ca3ef04bc8 java_beans_beancontext_BeanContextMembershipEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_beans_beancontext_BeanContextEvent

#include "java/beans/beancontext/BeanContextEvent.h"

#ifndef _JC_java_beans_beancontext_BeanContextMembershipEvent_H_
#define _JC_java_beans_beancontext_BeanContextMembershipEvent_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContext$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextMembershipEvent$sub_refs	_jc_java_beans_beancontext_BeanContextMembershipEvent$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextMembershipEvent$sub_nonrefs	_jc_java_beans_beancontext_BeanContextMembershipEvent$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextMembershipEvent$refs	_jc_java_beans_beancontext_BeanContextMembershipEvent$refs;
typedef struct _jc_java_beans_beancontext_BeanContextMembershipEvent$nonrefs	_jc_java_beans_beancontext_BeanContextMembershipEvent$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object	_jc_java_beans_beancontext_BeanContextMembershipEvent$object;

typedef const struct _jc_java_beans_beancontext_BeanContextMembershipEvent$vmethods	_jc_java_beans_beancontext_BeanContextMembershipEvent$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextMembershipEvent$vtable	_jc_java_beans_beancontext_BeanContextMembershipEvent$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextMembershipEvent$vtype	_jc_java_beans_beancontext_BeanContextMembershipEvent$vtype;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextMembershipEvent$method$_init$17633d25645e88a8(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_java_beans_beancontext_BeanContextMembershipEvent$method$_init$684ea38e627b4e04(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *, struct _jc_object *, struct _jc_object_array *);

// Virtual methods
extern jboolean _jc_java_beans_beancontext_BeanContextMembershipEvent$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextMembershipEvent$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *);
extern jint _jc_java_beans_beancontext_BeanContextMembershipEvent$method$size$345df5220fc60ade(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *);
extern _jc_object_array *_jc_java_beans_beancontext_BeanContextMembershipEvent$method$toArray$408321282fd84959(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextMembershipEvent$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_java_beans_beancontext_BeanContextMembershipEvent$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_java_beans_beancontext_BeanContextMembershipEvent$method_info$size$345df5220fc60ade;
extern _jc_method _jc_java_beans_beancontext_BeanContextMembershipEvent$method_info$toArray$408321282fd84959;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *);
	_jc_object_array	*(*toArray$408321282fd84959)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *);
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_beans_beancontext_BeanContextEvent$vmethods	java_beans_beancontext_BeanContextEvent;
	_jc_java_beans_beancontext_BeanContextMembershipEvent$vmethods	java_beans_beancontext_BeanContextMembershipEvent;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextMembershipEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$sub_refs {
	struct _jc_object	*children;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$refs {
    _jc_java_beans_beancontext_BeanContextMembershipEvent$sub_refs	java_beans_beancontext_BeanContextMembershipEvent;
    _jc_java_beans_beancontext_BeanContextEvent$sub_refs	java_beans_beancontext_BeanContextEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs	java_beans_beancontext_BeanContextEvent;
    _jc_java_beans_beancontext_BeanContextMembershipEvent$sub_nonrefs	java_beans_beancontext_BeanContextMembershipEvent;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object {
	_jc_java_beans_beancontext_BeanContextMembershipEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextMembershipEvent$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextMembershipEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextMembershipEvent$vtype _jc_java_beans_beancontext_BeanContextMembershipEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextMembershipEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextMembershipEvent$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextMembershipEvent_H_ */

==> jc-1.4.6.tar.gz: java/beans/beancontext/BeanContextMembershipEvent.h <==
// public class java.beans.beancontext.BeanContextMembershipEvent

// class file dependencies
// @dep_class 83892d580401761a java_beans_beancontext_BeanContextEvent
// @dep_class 5efb8ca3ef04bc8 java_beans_beancontext_BeanContextMembershipEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_beans_beancontext_BeanContextEvent

#include "java/beans/beancontext/BeanContextEvent.h"

#ifndef _JC_java_beans_beancontext_BeanContextMembershipEvent_H_
#define _JC_java_beans_beancontext_BeanContextMembershipEvent_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContext$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextMembershipEvent$sub_refs	_jc_java_beans_beancontext_BeanContextMembershipEvent$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextMembershipEvent$sub_nonrefs	_jc_java_beans_beancontext_BeanContextMembershipEvent$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextMembershipEvent$refs	_jc_java_beans_beancontext_BeanContextMembershipEvent$refs;
typedef struct _jc_java_beans_beancontext_BeanContextMembershipEvent$nonrefs	_jc_java_beans_beancontext_BeanContextMembershipEvent$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object	_jc_java_beans_beancontext_BeanContextMembershipEvent$object;

typedef const struct _jc_java_beans_beancontext_BeanContextMembershipEvent$vmethods	_jc_java_beans_beancontext_BeanContextMembershipEvent$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextMembershipEvent$vtable	_jc_java_beans_beancontext_BeanContextMembershipEvent$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextMembershipEvent$vtype	_jc_java_beans_beancontext_BeanContextMembershipEvent$vtype;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextMembershipEvent$method$_init$17633d25645e88a8(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_beancontext_BeanContextMembershipEvent$method$_init$684ea38e627b4e04(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_beans_beancontext_BeanContextMembershipEvent$method$contains$d3bd70da40f05cb1(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextMembershipEvent$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_beans_beancontext_BeanContextMembershipEvent$method$size$345df5220fc60ade(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_beans_beancontext_BeanContextMembershipEvent$method$toArray$408321282fd84959(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextMembershipEvent$method_info$contains$d3bd70da40f05cb1;
extern _jc_method _jc_java_beans_beancontext_BeanContextMembershipEvent$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_java_beans_beancontext_BeanContextMembershipEvent$method_info$size$345df5220fc60ade;
extern _jc_method _jc_java_beans_beancontext_BeanContextMembershipEvent$method_info$toArray$408321282fd84959;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$vmethods {
	jboolean	(*contains$d3bd70da40f05cb1)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*toArray$408321282fd84959)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_beans_beancontext_BeanContextEvent$vmethods	java_beans_beancontext_BeanContextEvent;
	_jc_java_beans_beancontext_BeanContextMembershipEvent$vmethods	java_beans_beancontext_BeanContextMembershipEvent;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextMembershipEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$sub_refs {
	struct _jc_object	*children;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$refs {
    _jc_java_beans_beancontext_BeanContextMembershipEvent$sub_refs	java_beans_beancontext_BeanContextMembershipEvent;
    _jc_java_beans_beancontext_BeanContextEvent$sub_refs	java_beans_beancontext_BeanContextEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs	java_beans_beancontext_BeanContextEvent;
    _jc_java_beans_beancontext_BeanContextMembershipEvent$sub_nonrefs	java_beans_beancontext_BeanContextMembershipEvent;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextMembershipEvent$object {
	_jc_java_beans_beancontext_BeanContextMembershipEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextMembershipEvent$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextMembershipEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextMembershipEvent$vtype _jc_java_beans_beancontext_BeanContextMembershipEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextMembershipEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextMembershipEvent$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextMembershipEvent_H_ */
